@@ -210,13 +210,6 @@ static gchar *visual_alerts_section[] = {
     NULL
 };
 
-static gchar *shortcuts_section[] = {
-    "stickykeys_frame",
-    "slowkeys_frame",
-    "bouncekeys_frame",
-    NULL
-};
-
 static void
 cc_ua_panel_section_switched (GObject    *object,
                               GParamSpec *pspec,
@@ -300,8 +293,9 @@ gconf_on_off_peditor_new (CcUaPanelPrivate  *priv,
 /* seeing section */
 #define GTK_THEME_KEY "gtk-theme"
 #define ICON_THEME_KEY "icon-theme"
-#define CONTRAST_MODEL_THEME_COLUMN 3
+#define CONTRAST_MODEL_THEME_COLUMN 2
 #define DPI_MODEL_FACTOR_COLUMN 2
+#define DPI_MODEL_FACTOR_CALC_COLUMN 3
 
 static void text_scaling_factor_combo_box_changed (GtkComboBox *box, CcUaPanel *panel);
 
@@ -327,6 +321,26 @@ text_scaling_factor_notify_cb (GSettings   *settings,
   combo = WID (priv->builder, "seeing_text_size_combobox");
   model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
 
+  /* Recalculate the font sizes so that
+   * their size is about constant when changing text size */
+  valid = gtk_tree_model_get_iter_first (model, &iter);
+  while (valid)
+    {
+      gfloat factor;
+
+      gtk_tree_model_get (model, &iter,
+                          DPI_MODEL_FACTOR_COLUMN, &factor,
+                          -1);
+
+      factor /= conf_value;
+
+      gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+                          DPI_MODEL_FACTOR_CALC_COLUMN, factor,
+                          -1);
+
+      valid = gtk_tree_model_iter_next (model, &iter);
+    }
+
   /* find the closest match in the combobox model */
   distance = 1e6;
   valid = gtk_tree_model_get_iter_first (model, &iter);
@@ -530,7 +544,11 @@ visual_bell_type_notify_cb (GConfClient *client,
                             CcUaPanel   *panel)
 {
   GtkWidget *widget;
-  const gchar *value = gconf_value_get_string (entry->value);
+  const gchar *value;
+
+  g_return_if_fail (entry != NULL);
+
+  value = gconf_value_get_string (entry->value);
 
   if (!strcmp ("frame_flash", value))
     widget = WID (panel->priv->builder, "hearing_flash_window_title_button");
@@ -562,7 +580,7 @@ hearing_sound_preferences_clicked (GtkButton *button,
   CcShell *shell;
 
   shell = cc_panel_get_shell (CC_PANEL (panel));
-  cc_shell_set_active_panel_from_id (shell, "sound", NULL);
+  cc_shell_set_active_panel_from_id (shell, "sound", NULL, NULL);
 }
 
 static void
@@ -614,7 +632,7 @@ typing_keyboard_preferences_clicked (GtkButton *button,
   CcShell *shell;
 
   shell = cc_panel_get_shell (CC_PANEL (panel));
-  cc_shell_set_active_panel_from_id (shell, "keyboard", NULL);
+  cc_shell_set_active_panel_from_id (shell, "keyboard", NULL, NULL);
 }
 
 static void
@@ -629,7 +647,7 @@ cc_ua_panel_init_keyboard (CcUaPanel *self)
 
   /* enable shortcuts */
   w = WID (priv->builder, "typing_keyboard_toggle_checkbox");
-  settings_on_off_editor_new (priv, priv->kb_settings, "enable", w, shortcuts_section);
+  g_settings_bind (priv->kb_settings, "enable", w, "active", G_SETTINGS_BIND_DEFAULT);
 
   /* sticky keys */
   w = WID (priv->builder, "typing_sticky_keys_switch");
@@ -684,7 +702,7 @@ pointing_mouse_preferences_clicked_cb (GtkButton *button,
   CcShell *shell;
 
   shell = cc_panel_get_shell (CC_PANEL (panel));
-  cc_shell_set_active_panel_from_id (shell, "mouse", NULL);
+  cc_shell_set_active_panel_from_id (shell, "mouse", NULL, NULL);
 }
 
 static void
@@ -767,6 +785,7 @@ cc_ua_panel_init (CcUaPanel *self)
   priv->interface_settings = g_settings_new ("org.gnome.desktop.interface");
   g_signal_connect (priv->interface_settings, "changed",
                     G_CALLBACK (interface_settings_changed_cb), self);
+  interface_settings_changed_cb (priv->interface_settings, "gtk-theme", self);
 
   priv->kb_settings = g_settings_new ("org.gnome.desktop.a11y.keyboard");
   priv->mouse_settings = g_settings_new ("org.gnome.desktop.a11y.mouse");
